import setuptools

with open('README.md', 'r') as fh:
    long_description = fh.read()

setuptools.setup(name='configparsertool',
                 version='1.0.1',
                 author='bjtj',
                 author_email='bjtj10@gmail.com',
                 description='python configparser tool',
                 long_description=long_description,
                 long_description_content_type='text/markdown',
                 url='https://github.com/bjtj/python-configparser-tool',
                 packages=setuptools.find_packages(),
                 classifiers=[
                     'Programming Language :: Python :: 3',
                     'License :: OSI Approved :: MIT License',
                     'Operating System :: OS Independent',
                 ],
)



try:
    import ConfigParser as configparser
except Exception:
    import configparser


def getvalues(filepath, section, keys):
    parser = configparser.ConfigParser()
    if not parser.read(filepath):
        raise ValueError('read() failed -- "{}"'.format(filepath))
    values = []
    for key in keys:
        values.append(parser.get(section, key))
    return values
        
